function I = fbprec(F, theta, N, interp_method, filter)
% FBPREC 2-D Filtered Back Projection Image Reconstruction.
% Filtered Backprojection Reconstruction routine.
%
%    I = FBPREC(F, THETA, N, INT_METHOD, FILTER) returns an image
%    reconstructed from the radial k-space data matrix F or projection data
%    in the 2-D array F. The rows of F are parallel beam projection data.
%    FBPREC assumes that the center of rotation is the center point of the
%    projections, which is defined as ceil(size(F,2)/2) as same as defined
%    in IRADON.
% 
%    THETA describes the angles (in degrees) at which the projections were
%    taken. See IRADON for more details. 
%
%    N is a scalar that specifies the number of rows and columns in the
%    reconstructed image (OUTPUT_SIZE in IRADON).
%
%    FILTER specifies the filter to use for frequency domain filtering. See
%    IRADON for standard filters used for the routine.
%
%    See also IRADON, DCEKR, and SLRADIAL.
%
%    Created and modified by Yuttapong Jiraraksopakun
%
%    Copyrigt 2007, Jim Ji, Texas A&M University. All Rights Reserved. 
%


% for ii = 1:N
%     r(:,ii) = transpose([ifftshift(ifft(ifftshift(F(ii,:)))) 0]);
% end

if mod(size(F,2),2) == 0
    r = transpose([ifftshift(ifft(ifftshift(F, 2), [], 2), 2) zeros(N,1)]);
else
    r = transpose(ifftshift(ifft(ifftshift(F, 2), [], 2), 2));
end

if isreal(r)
    I = iradon( r, theta, interp_method, filter, 1, N);
else
    Ir = iradon( real(r), theta, interp_method, filter, 1, N );
    Im = iradon( imag(r), theta, interp_method, filter, 1, N );
    I = abs(Ir+sqrt(-1)*Im);
end