function j = jinc(x)
% JINC besselj(1,x)/(x) function.
%    JINC(X) returns a matrix whose elements are the jinc of the elements 
%     of X, i.e.
%          y = J1(x)/(x)           if x ~= 0
%            = 1/2                 if x == 0
%     where x is an element of the input matrix and y is the resultant
%     output element.
%  
%     % Example of a jinc function for a linearly spaced vector:
%     t = linspace(-15,15);
%     y = jinc(t);
%     plot(t,y);
%     xlabel('Time (sec)');ylabel('Amplitude'); title('Jinc Function')
%
%     See also SINC, SQUARE, SIN, COS, CHIRP, DIRIC, GAUSPULS, PULSTRAN,
%     RECTPULS, and TRIPULS.
%
%    Copyrigt 2007, Jim Ji, Texas A&M University. All Rights Reserved. 
%

sizx = size(x);
x = x(:);
j = zeros(prod(sizx),1);
ind = find(x~=0);
j(ind) = real(besselj(1,x(ind)))./x(ind);
j(find(x==0)) = 1/2;
j = reshape(j,sizx);