function C = tcac(t)
% generate a washin/washout curve
%    Copyrigt 2007, Jim Ji, Texas A&M University. All Rights Reserved. 
%

t = t(:)';
D = 0.3; % Dose = 0.3 mmol/kg
Vp = 0.0360; % Volume of the plasma (L/kg)
Ve = 0.0528; % Volume of the tumor extravascular extracellular space (EES) (L/kg)
Kpe = 0.0082; % Contrast agent transfer rate between plasma and EES (simple diffusive transport) (L/kg*min)
Kpk = 0.0024; % Contrast agent transfer rate between plasma and kidneys (L/kg*min)
KptByVt = [0.001 0.005 0.015 0.030]'; % (L/kg*sec)
ve = 0.111; % Volume fraction of the tumor EES
vp = 0; % Volume fraction of the plasma

% Simple diffusive transport case
a1 = Ve/(Vp*(Vp+Ve));
a2 = 1/(Vp+Ve);
alpha = (Kpe/60)*(Vp+Ve)/(Vp*Ve);
beta = (Kpk/60)/(Vp+Ve);

%C = D*(a1*(vp+((ve*KptByVt)./(KptByVt-alpha)))*exp(-alpha*t)+a2*(vp+((ve*KptByVt)./(KptByVt-beta)))*exp(-beta*t)-((a1*(ve*KptByVt)./(KptByVt-alpha))+((a2*(ve*KptByVt)./(KptByVt-beta))))*exp(-KptByVt*t));
C1 = (a1*(vp+(ve)./(1-alpha./KptByVt))*exp(-alpha*t));
C2 = (a2*(vp+(ve)./(1-beta./KptByVt))*exp(-beta*t));
C3 = (((a1*ve)./(1-alpha./KptByVt)+(a2*ve)./(1-beta./KptByVt))*ones(1,length(t))).*exp(-KptByVt*t);
C = D*(C1+C2-C3);